Dear User,<br/>
New topic(<a href="{{ topic_url }}">{{ topic.title }}</a>) has been created in forum and its status be <strong>Draft</strong>.
You are recieving this notification because, you have enable email settings option in the profile.
<br/>
You can view all the topic here <a href="{{ host_url }}">forum</a>

