Dear User,<br/>
New comment({{ comment.comment }}) has been created for the topic(<a href="{{topic_url}}">{{ comment.topic.title }}</a>) at {{ comment.created_on }}<br/>
You are recieving this notification because, you have enabled email settings option in the profile.
<br/>
You can view all the topic here <a href="{{ host_url }}">forum</a>

