{% extends 'forum/base.html' %}
{% block stage %}
   <div class="main_container">
     <div class="container">
        <div class="row middle_container">
          {% include 'forum/left_menu.html' %}
          <div class="main_left_container col-md-9 col-md-pull-3 col-sm-9 col-sm-pull-3 col-sm-8 col-xs-12">
            <div class="panel panel-default">
              <div class="panel-body">
                <!-- category section starts here-->
             <div class="Users_container row">
               <h3 class="create_topic_heading">All Badges</h3>
               <div class="row">
                 <div class="badges_row">
                 {% for badge in badges_list %}
                  <div class="col-md-4 col-sm-4 badge_item">
                    <div class="badge_content">
                      <div class="title"><a href="#">{{ badge.title }}</a></div>
                      <div class="content">{{ badge.description }}</div>
                      <span class="count">{{badge.get_users|length}}</span>
                    </div>
                  </div>
                  {% endfor %}
                  </div>
               </div>
              </div>
              <!-- category section ends here-->
              </div>
            </div>
          </div>
        </div>
     </div>
   </div>
{% endblock %}