Dear User,<br/>
New comment({{ comment.title }}) has been created for the topic, and you have mentioned in the topic(<a href="{{topic_url}}">{{ comment.topic.title }}</a>).
You are recieving this notification because, you have enable email settings option in the profile.
<br/>
You can view all the topic here <a href="{{ host_url }}">forum</a>

